function newGps = gpscirctimelag(origGps,secOffset)
%GPSCIRCTIMELAG Offset GPS value by time lag allowing 'circular' wrap around end of epochs
%
%SYNOPSIS
%   NEWGPS = gpscirctimelag(ORIGGPS, SECOFFSET)
%
%INPUT
%   ORIGGPS     original GPS structure (sec,ns)
%   SECOFFSET   offset time (in GPS struct or digital seconds)
%   *** We assume the offset time is how much the raw time series
%           is shifted.  For reconstructed events, we need to 
%           shift in the OPPOSITE direction.
%
%OUTPUT
%   NEWGPS      new GPS structure offset in seconds
%   *** Uses Epochs to do circular shifts !!!
%       -- requires epochlimits
%
%AUTHOR
%   Keith Thorne <keith.thorne@ligo.org>

% $Id: gpscirctimelag.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% SET new GPS time = original GPS time - input time offset
% LOOP over GPS times
%   GET limits of epoch for original GPS time
%   IF limits are found
%       CALCULATE any required shift to keep GPS within epoch limits
%           (using modular math to wrap around the ends)
%       ADD shift to new GPS time
%   ELSE
%       SET new GPS time to null value
%   ENDIF
% ENDLOOP
newGps = gpsdiff(origGps,secOffset);
[mrows,ncols]=size(origGps);
for ir = 1:mrows
    for ic = 1:ncols
        [epochStart,epochDur]=epochlimits('get',origGps(ir,ic).sec);
        if(~isempty(epochStart))
% - To preserve the accuracy of the nano-second portion, we subtract off
%   the large GPS offset using the start of the epoch.  When we are done, 
%    we add it back
            newTime = gps2time(gpsdiff(newGps(ir,ic),epochStart));
            circNewTime = mod(newTime,epochDur);
%D        if(circNewTime ~= newTime )
%D            fprintf(1,' GPSCIRCTIMELAG GPS %d epoch %d shift %d  newSec %d\n',...
%D                  newGps(ir,ic).sec,epochStart,secOffset,circNewTime);
%D        end
            newGps(ir,ic) = gpssum(time2gps(circNewTime),epochStart);
        end
    end
end
return
